<?php

class SmartContactBox extends WP_Widget {

    public $defaults;

    public function __construct() {
        $this->defaults = array(
            'title' => esc_html__('Contacts', 'laundry'),
            'phone' => '+1-800-123-45-67',
            'address' => '5604 Willow Crossing Ct, Clifton, VA, 20124',
            'hours' => 'Mon - Fri: 9:00am - 7:00pm
                                    <br> Sat - Sun: 11:00am - 16:00pm',
        );

        parent::__construct(
                'smart_contact_box', // Base ID  
                esc_html__('Service Contact Box', 'laundry'), // Name  
                array(
            'description' => esc_html__('Side Bar Contact Box.', 'laundry')
                )
        );
    }   

    function form($instance) {
        $instance = wp_parse_args((array) $instance, $this->defaults);
        ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>">
                <strong><?php esc_html_e('Title', 'laundry') ?>:</strong><br /><input class="widefat" type="text" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" value="<?php echo esc_attr($instance['title']); ?>" />
            </label>
        </p> 
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('phone')); ?>"><?php esc_html_e('Phone', 'laundry') ?></label>
            <textarea class="widefat" id="<?php echo esc_attr($this->get_field_id('phone')); ?>" name="<?php echo esc_attr($this->get_field_name('phone')); ?>"><?php echo wp_kses_post($instance['phone']); ?></textarea>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('address')); ?>"><?php esc_html_e('Address', 'laundry') ?></label>
            <textarea class="widefat" id="<?php echo esc_attr($this->get_field_id('address')); ?>" name="<?php echo esc_attr($this->get_field_name('address')); ?>"><?php echo wp_kses_post($instance['address']); ?></textarea>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('hours')); ?>"><?php esc_html_e('Hours', 'laundry') ?></label>
            <textarea class="widefat" id="<?php echo esc_attr($this->get_field_id('hours')); ?>" name="<?php echo esc_attr($this->get_field_name('hours')); ?>"><?php echo wp_kses_post($instance['hours']); ?></textarea>
        </p>
        <?php
    }

    function widget($args, $instance) {
        extract($args);
        // print_r($instance);
        echo wp_kses_post($before_widget);
        if (!empty($instance['title'])) {
            $title = empty($instance['title']) ? ' ' : apply_filters('widget_title', $instance['title']);
            echo wp_kses_post($before_title . $title . $after_title);
        };
        ?>


        <div class="contact-box">
            <div class="contact-box-row">
                <i class="icon-map-pointer"></i>
                <div class="contact-box-row-title"><b>Our address:</b></div>
        <?php if (!empty($instance['address'])): ?>
                    <div>  <?php echo wp_kses_post($instance['address']); ?> 
                    </div>
        <?php endif; ?>
            </div>
            <div class="contact-box-row">
                <i class="icon-telephone"></i>
                <div class="contact-box-row-title"><b>Call us:</b></div>
        <?php if (!empty($instance['phone'])): ?>
                    <div>  <?php echo wp_kses_post($instance['phone']); ?> 
                    </div>
        <?php endif; ?>
            </div>
            <div class="contact-box-row">
                <i class="icon-clock"></i>
                <div class="contact-box-row-title"><b>Work Time:</b></div>
        <?php if (!empty($instance['hours'])): ?>
                    <div>  <?php echo wp_kses_post($instance['hours']); ?> 
                    </div>
        <?php endif; ?>
            </div>
        </div>
        <?php
        echo wp_kses_post($after_widget);
    }

    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['phone'] = $new_instance['phone'];
        $instance['address'] = $new_instance['address'];
        $instance['hours'] = $new_instance['hours'];
        return $instance;
    }

}
function laundry_smart_contact_list_widget() {
    register_widget( 'SmartContactBox' );
}
add_action( 'widgets_init', 'laundry_smart_contact_list_widget' );

