<?php
/**
 * A custom WordPress comment walker class to implement the Bootstrap 3 Media object in wordpress comment list.
 *
 * @package     WP Bootstrap Comment Walker
 * @version     1.0.0
 * @author      Edi Amin <to.ediamin@gmail.com>
 * @license     http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link        https://github.com/ediamin/wp-bootstrap-comment-walker
 */
class Laundry_Comment_Walker extends Walker_Comment {
	/**
	 * Output a comment in the HTML5 format.
	 *
	 * @access protected
	 * @since 1.0.0
	 *
	 * @see wp_list_comments()
	 *
	 * @param object $comment Comment to display.
	 * @param int    $depth   Depth of comment.
	 * @param array  $args    An array of arguments.
	 */
	protected function html5_comment( $comment, $depth, $args ) {
		$tag = ( 'div' === $args['style'] ) ? 'div' : 'li';
		if( $depth *1 > 1 ){
			$is_replay = 'replay';
		}else{
			$is_replay = '';
		}
?>		

		<<?php print $tag; ?> id="comment-<?php comment_ID(); ?>" <?php comment_class( $this->has_children ? 'parent media' : 'media' . ' ' . $is_replay ); ?>>
			<?php if ( 0 != $args['avatar_size'] ): ?>
			<div class="media-left userpic">
				<a href="<?php echo get_comment_author_url(); ?>" class="media-object">
					<?php echo get_avatar( $comment, $args['avatar_size'] ); ?>
				</a>
			</div>
			<?php endif; ?>

			<div class="media-body text">
					<div class="meta">
					<?php printf( '<span class="author"><i>%s</i></span> | ', get_comment_author_link() ); ?>
					<span class="date"><?php printf( esc_html_x( '%1$s at %2$s', '1: date, 2: time', 'laundry' ), get_comment_date( "F d Y" ), get_comment_time('') ); ?></span>
					<?php
						comment_reply_link( array_merge( $args, array(
							'add_below' => 'div-comment',
							'depth'     => $depth,
							'max_depth' => $args['max_depth'],
							'before'    => '',
							'after'     => '',
							"class='reply",
						) ) );	
					?>
					</div>
					
					<?php if ( '0' == $comment->comment_approved ) : ?>
					<p class="comment-awaiting-moderation label label-info"><?php esc_html_e( 'Your comment is awaiting moderation.', 'laundry' ); ?></p>
					<?php endif; ?>				

					<div class="comment-content">
						<?php comment_text(); ?>
					</div><!-- .comment-content -->
					
					<ul class="list-inline">
						<?php edit_comment_link( esc_html__( 'Edit', 'laundry' ), '<li class="edit-link">', '</li>' ); ?>


					</ul>
				
			</div>		
<?php
	}	
}