<?php
/**
 * Sample implementation of the Custom Header feature.
 *
 * You can add an optional custom header image to header.php like so ...
 *
	<?php if ( get_header_image() ) : ?>
	<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
		<img src="<?php header_image(); ?>" width="<?php echo esc_attr( get_custom_header()->width ); ?>" height="<?php echo esc_attr( get_custom_header()->height ); ?>" alt="">
	</a>
	<?php endif; // End header image check. ?>
 *
 * @link https://developer.wordpress.org/themes/functionality/custom-headers/
 *
 * @package Laundry
 */

/**
 * Set up the WordPress core custom header feature.
 *
 * @uses laundry_header_style()
 */
function laundry_custom_header_setup() {
	add_theme_support( 'custom-header', apply_filters( 'laundry_custom_header_args', array(
		'default-image'          => '',
		'default-text-color'     => '000000',
		'width'                  => 1000,
		'height'                 => 250,
		'flex-height'            => true,
		'wp-head-callback'       => 'laundry_header_style',
	) ) );
}
add_action( 'after_setup_theme', 'laundry_custom_header_setup' );

if ( ! function_exists( 'laundry_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog.
 *
 * @see laundry_custom_header_setup().
 */
function laundry_header_style() {
	$header_text_color = get_header_textcolor();

	/*
	 * If no custom options for text are set, let's bail.
	 * get_header_textcolor() options: Any hex value, 'blank' to hide text. Default: HEADER_TEXTCOLOR.
	 */
	if ( HEADER_TEXTCOLOR === $header_text_color ) {
		return;
	}

	if ( ! display_header_text() ) :
	
		$header_css = '.site-title,
		.site-description {
			position: absolute;
			clip: rect(1px, 1px, 1px, 1px);
		}';

	// If the user has set a custom color for the text use that.
	else :

		$header_css = '.site-title a,
		.site-description {
			color: #'.esc_attr( $header_text_color ).';
		}';

	endif;
	if(wp_style_is('laundry-custom')){
		wp_add_inline_style('laundry-custom', $header_css);
	}
}
endif;
