<?php

	if ( ! class_exists( 'Redux' ) ) {
		return;
	}

	// This is your option name where all the Redux data is stored.
    $opt_name = "laundry_opt";

    $theme = wp_get_theme(); // For use with some settings. Not necessary.
   	$opt_prefix = 'laundry';

    $args = array(
		// TYPICAL -> Change these values as you need/desire
		'opt_name'             => $opt_name,
		// This is where your data is stored in the database and also becomes your global variable name.
		'display_name'         => $theme->get( 'Name' ),
		// Name that appears at the top of your panel
		'display_version'      => $theme->get( 'Version' ),
		// Version that appears at the top of your panel
		'menu_type'            => 'menu',
		//Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
		'allow_sub_menu'       => true,
		// Show the sections below the admin menu item or not
		'menu_title'           => esc_html__('Laundry Options', 'laundry'),
		'page_title'           => esc_html__('Laundry Options', 'laundry'),
		// You will need to generate a Google API key to use this feature.
		// Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
		'google_api_key'       => '',
		// Set it you want google fonts to update weekly. A google_api_key value is required.
		'google_update_weekly' => false,
		// Must be defined to add google fonts to the typography module
		'async_typography'     => false,
		// Use a asynchronous font on the front end or font string
		//'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
		'admin_bar'            => true,
		// Show the panel pages on the admin bar
		'admin_bar_icon'       => 'dashicons-portfolio',
		// Choose an icon for the admin bar menu
		'admin_bar_priority'   => 50,
		// Choose an priority for the admin bar menu
		'global_variable'      => '',
		// Set a different name for your global variable other than the opt_name
		'dev_mode'             => false,
		// Show the time the page took to load, etc
		'update_notice'        => true,
		// If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
		'customizer'           => false,
		// Enable basic customizer support
		//'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
		//'disable_save_warn' => true,                    // Disable the save warning when a user changes a field
		// OPTIONAL -> Give you extra features
		'page_priority'        => null,
		// Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
		'page_parent'          => 'themes.php',
		// For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
		'page_permissions'     => 'manage_options',
		// Permissions needed to access the options panel.
		'menu_icon'            => '',
		// Specify a custom URL to an icon
		'last_tab'             => '',
		// Force your panel to always open to a specific tab (by id)
		'page_icon'            => 'icon-themes',
		// Icon displayed in the admin panel next to your menu_title
		'page_slug'            => '',
		// Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
		'save_defaults'        => true,
		// On load save the defaults to DB before user clicks save or not
		'default_show'         => false,
		// If true, shows the default value next to each field that is not the default value.
		'default_mark'         => '',
		// What to print by the field's title if the value shown is default. Suggested: *
		'show_import_export'   => true,
		// Shows the Import/Export panel when not used as a field.
		// CAREFUL -> These options are for advanced use only
		'transient_time'       => 60 * MINUTE_IN_SECONDS,
		'output'               => true,
		// Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
		'output_tag'           => true,
		// Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
		// 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.
		// FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
		'database'             => '',
		// possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
		'use_cdn'              => true,
		// If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.
		// HINTS
		'hints'                => array(
			'icon'          => 'el el-question-sign',
			'icon_position' => 'right',
			'icon_color'    => 'lightgray',
			'icon_size'     => 'normal',
			'tip_style'     => array(
				'color'   => 'red',
				'shadow'  => true,
				'rounded' => false,
				'style'   => '',
			),
			'tip_position'  => array(
				'my' => 'top left',
				'at' => 'bottom right',
			),
			'tip_effect'    => array(
				'show' => array(
					'effect'   => 'slide',
					'duration' => '500',
					'event'    => 'mouseover',
				),
				'hide' => array(
					'effect'   => 'slide',
					'duration' => '500',
					'event'    => 'click mouseleave',
				),
			),
		)
	);


	Redux::setArgs( $opt_name, $args );

	Redux::setSection( $opt_name, array(
		'title'            => esc_html__('Header Settings', 'laundry'),
		'id'               => 'header_settings',
		'desc'             => esc_html__('All header settings', 'laundry'),
		'customizer_width' => '400px',
		'icon'             => 'el el-website',
		'fields'           => array(
            array(
				'id'       => $opt_prefix.'-site-preloader',
				'type'     => 'switch',
				'title'    => esc_html__('Display preloader before page load', 'laundry'),
				'subtitle' => esc_html__('Enable or Disable site preloader', 'laundry'),
				'default'  => false,
				'on'	   => esc_html__('Enable', 'laundry'),
				'off'	   => esc_html__('Disable', 'laundry'),
			),
            array(
                'id'       => $opt_prefix.'-is_sticky_header',
                'type'     => 'switch',
                'title'    => esc_html__('Display Header Sticky', 'laundry'),
                'subtitle' => esc_html__('Enable or Disable Header Sticky', 'laundry'),
                'default'  => true,
                'on'       => esc_html__('Enable', 'laundry'),
                'off'      => esc_html__('Disable', 'laundry'),
            ),
			
			array(
				'id'       => $opt_prefix.'-header-image',
				'type'     => 'media',
				'url'       => true,
				'compiler'  => 'true',
                'desc'      => esc_html__('Basic media uploader with disabled URL input field.', 'laundry'),
				'subtitle'  => esc_html__('Add/Upload Menu Background Image using the WordPress native uploader', 'laundry'),
				'title'    => esc_html__('Menu Background Image', 'laundry'),
				'default'     => array(
					'url'       => LAUNDRY_THEME_URI . '/images/box-nav.jpg',
				),
			),
			
			array(
				'id'       => $opt_prefix.'-header-color',
				'type'     => 'color',
				'title'    => __('Menu Background Color', 'laundry'), 
				'subtitle' => __('Pick a background color for the Menu (default: #009BD8).', 'laundry'),
				'default'  => '#009BD8',
				'validate' => 'color',
			),
			
			
			
			
            array(
				'id'       => $opt_prefix.'-service-show-breadcrumb',
				'type'     => 'switch',
				'title'    => esc_html__('Enable/Disable Breadcrumb in Service Page', 'laundry'),
				'subtitle' => esc_html__('Enable/Disable Breadcrumb Page', 'laundry'),
				'default'  => true,
				'on'	   => esc_html__('Enable', 'laundry'),
				'off'	   => esc_html__('Disable', 'laundry'),
			),
			array(
				'id'       => $opt_prefix.'-logo',
				'type'     => 'media',
				'url'       => true,
				'compiler'  => 'true',
                'desc'      => esc_html__('Basic media uploader with disabled URL input field.', 'laundry'),
				'subtitle'  => esc_html__('Add/Upload logo using the WordPress native uploader', 'laundry'),
				'title'    => esc_html__('Site Logo', 'laundry'),
				'default'     => array(
					'url'       => LAUNDRY_THEME_URI . '/images/logo.png',
				),
			),
			array(
				'id'       => $opt_prefix.'-is_mobile_menu_icon',
                'type'     => 'switch',
                'title'    => esc_html__('Custom Mobile Menu Icon', 'laundry'),
                'subtitle' => esc_html__('Enable or Disable Custom Mobile Menu Icon', 'laundry'),
                'default'  => false,
                'on'       => esc_html__('Enable', 'laundry'),
                'off'      => esc_html__('Disable', 'laundry'),
            ),
            array(
				'id'       => $opt_prefix.'-mobile_menu_icon',
				'type'     => 'media',
				'url'       => true,
				'compiler'  => 'true',
                'desc'      => esc_html__('Mobile Menu Icon.', 'laundry'),
				'subtitle'  => esc_html__('Add/Upload logo using the WordPress native uploader', 'laundry'),
				'title'    => esc_html__('Mobile Menu Icon', 'laundry'),
				'default'     => array(
					//'url'       => LAUNDRY_THEME_URI . '/images/logo.png',
				),
			),
			array(
                'id'        => $opt_prefix.'-site-favicon',
                'type'      => 'media',
                'url'       => true,
                'title'     => esc_html__('Favicon URL', 'laundry'),
                'compiler'  => 'true',
                'desc'      => esc_html__('Set favicon for your theme', 'laundry'),
                'subtitle'  => esc_html__('Upload favicon for the theme', 'laundry'),
                'default'   => array('url' => LAUNDRY_THEME_URI.'/images/fav.ico'),
            ),
            array(
                'id'       => 'Header',
                'type'     => 'section',
                'title'    => esc_html__( 'Header Content', 'laundry' ),
                'subtitle' => esc_html__( 'With the "section" field you can create indented option sections.', 'laundry' ),
                'indent'   => true, // Indent all options below until the next 'section' option is set.
            ),
			array(
				'id'       => $opt_prefix.'-display-header-left-text',
				'type'     => 'switch',
				'title'    => esc_html__('Display header left text', 'laundry'),
				'subtitle' => esc_html__('Enable or disable header left text', 'laundry'),
				'default'  => false,
				'on'	   => esc_html__('Enable', 'laundry'),
				'off'	   => esc_html__('Disable', 'laundry'),
			),
            array(
                'id'       => $opt_prefix.'-header-left-1st-line',
                'type'     => 'text',
				'title'    => 'Header left address 1st line',
				'default'    => '5604 Willow Crossing Ct,',
            ),
            array(
                'id'       => $opt_prefix.'-header-left-2nd-line',
                'type'     => 'text',
				'title'    => 'Header left address 2nd line',
				'default'    => 'Clifton, VA, 20124',
            ),
				
            array(
                'id'       => 'Header2',
                'type'     => 'section',
                'title'    => ' ',
                'indent'   => true, // Indent all options below until the next 'section' option is set.
            ),
			array(
				'id'       => $opt_prefix.'-display-header-right-text',
				'type'     => 'switch',
				'title'    => esc_html__('Display header right text', 'laundry'),
				'subtitle' => esc_html__('Enable or disable header right text', 'laundry'),
				'default'  => false,
				'on'	   => esc_html__('Enable', 'laundry'),
				'off'	   => esc_html__('Disable', 'laundry'),
			),
            array(
                'id'       => $opt_prefix.'-header-right-1st-line',
                'type'     => 'text',
				'title'    => 'Header right 1st line',
				'default'    => '1 (800) 123-45-67',
            ),
            array(
                'id'       => $opt_prefix.'-header-right-2nd-line',
                'type'     => 'text',
				'title'    => 'Header right 2nd line',
				'default'    => 'Mon.-Fri. 7:00 AM to 7:00 PM',
            ),
            array(
                'id'       => $opt_prefix.'-header-right-email',
                'type'     => 'text',
				'title'    => 'Header right email small device',
				'default'    => 'noreply@envato.com',
            ),
            array(
                'id'   => 'section-info',
                'type' => 'info',
                'desc' => esc_html__( 'And now you can add more fields below and outside of the indent.', 'laundry' ),
            ),
		)
	) );
    
    Redux::setSection( $opt_name, array(
		'title'            => esc_html__('Blog Settings', 'laundry'),
		'id'               => 'blog_settings',
		'desc'             => esc_html__('Blog Settings', 'laundry'),
		'customizer_width' => '400px',
		'icon'             => 'el el-website',
		'fields'           => array(
            array(
                'id'       => 'blogpost_layout_view',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Default page layout', 'laundry' ),
					 'options'  => array(
						  'classic-view'      => array(
								'alt'   => 'classic-view', 
								'img'   => LAUNDRY_IMG_URL . '/blog-classic-view.jpg'
						  ),
						  'grid-view'      => array(
								'alt'   => 'grid-view', 
								'img'   => LAUNDRY_IMG_URL . '/blog-grid-view.jpg'
						  ),
					 ),
					 'default' => 'classic-view'
            ),
            array(
                'id'       => 'blogpost_pagination_load',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Blog pagination style', 'laundry' ),
					 'options'  => array(
						  'pagination'      => array(
								'alt'   => 'classic-view', 
								'img'   => LAUNDRY_IMG_URL . '/blog-pagination.jpg'
						  ),
						  'navigation'      => array(
								'alt'   => 'grid-view', 
								'img'   => LAUNDRY_IMG_URL . '/blog-post-navigation.jpg'
						  ),
						  'ajax_load'      => array(
								'alt'   => 'grid-view', 
								'img'   => LAUNDRY_IMG_URL . '/blog-post-ajax-loading.jpg'
						  ),
					 ),
					 'default' => 'pagination'
            ),
            array(
				'id'       => $opt_prefix.'-blog-show-breadcrumb',
				'type'     => 'switch',
				'title'    => esc_html__('Enable/Disable Breadcrumb', 'laundry'),
				'subtitle' => esc_html__('Enable/Disable Breadcrumb', 'laundry'),
				'default'  => true,
				'on'	   => esc_html__('Enable', 'laundry'),
				'off'	   => esc_html__('Disable', 'laundry'),
			),

    )));
    
    Redux::setSection( $opt_name, array(
		'title'            => esc_html__('Footer Settings', 'laundry'),
		'id'               => 'footer_settings',
		'customizer_width' => '400px',
		'icon'             => 'el el-website',
		'fields'           => array(
			array(
				'id'       => $opt_prefix.'-footer-logo',
				'type'     => 'media',
				'url'       => true,
				'compiler'  => 'true',
                'desc'      => esc_html__('Basic media uploader with disabled URL input field.', 'laundry'),
				'subtitle'  => esc_html__('Add/Upload logo using the WordPress native uploader', 'laundry'),
				'title'    => esc_html__('Site Logo', 'laundry'),
				'default'     => array(
					'url'       => LAUNDRY_THEME_URI . '/images/logo_footer.png',
				),
			),

            array(
                'id'       => 'footer-cont',
                'type'     => 'section',
                'title'    => ' ',
                'indent'   => true, // Indent all options below until the next 'section' option is set.
            ),
            array(
                'id'       => $opt_prefix.'-foot-bigtext-1st-line',
                'type'     => 'text',
				'title'    => 'Footer big text 1st line',
				'default'    => 'Get Started Today!',
            ),
            array(
                'id'       => $opt_prefix.'-foot-bigtext-2nd-line',
                'type'     => 'text',
				'title'    => 'Footer big text 2nd line',
				'default'    => '1 (800) 123-45-67',
            ),
				
            array(
                'id'   => 'foot-section-info-end',
                'type' => 'info',
            ),
			
			array(
				'id'       => $opt_prefix.'-footer-facebook',
				'type'     => 'text',
				'title'    => esc_html__('Facebook Link', 'laundry'),
				'default'  => '#'
			),
			array(
				'id'       => $opt_prefix.'-footer-twitter',
				'type'     => 'text',
				'title'    => esc_html__('Twitter Link', 'laundry'),
				'default'  => '#'
			),
			array(
				'id'       => $opt_prefix.'-footer-instagram',
				'type'     => 'text',
				'title'    => esc_html__('Instagram', 'laundry'),
				'default'  => '#'
			),
			array(
				'id'       => $opt_prefix.'-footer-linkedin',
				'type'     => 'text',
				'title'    => esc_html__('linkedin', 'laundry'),
				'default'  => ''
			),
			array(
				'id'       => $opt_prefix.'-footer-youtube',
				'type'     => 'text',
				'title'    => esc_html__('youtube', 'laundry'),
				'default'  => ''
			),
			array(
				'id'       => $opt_prefix.'-footer-pinterest',
				'type'     => 'text',
				'title'    => esc_html__('pinterest', 'laundry'),
				'default'  => ''
			),
			array(
				'id'       => $opt_prefix.'-footer-vimeo',
				'type'     => 'text',
				'title'    => esc_html__('vimeo', 'laundry'),
				'default'  => ''
			),
			

            array(
                'id'       => 'foot',
                'type'     => 'section',
                'title'    => esc_html__( 'Footer Bottom', 'laundry' ),
                'subtitle' => esc_html__( 'With the "section" field you can create indented option sections.', 'laundry' ),
                'indent'   => true, // Indent all options below until the next 'section' option is set.
            ),
			array(
				'id'       => $opt_prefix.'-footer-copyright',
				'type'     => 'textarea',
				'title'    => esc_html__('Footer copyright', 'laundry'),
				'default'    => '&copy; 2017 Laundry & Dry Cleaning. All Rights Reserved.',
			),
            array(
                'id'       => $opt_prefix.'-footer-addr-line',
                'type'     => 'text',
				'title'    => 'Footer address line',
				'default'    => '5604 Willow Crossing Ct, Clifton, VA, 20124',
            ),
            array(
                'id'       => $opt_prefix.'-footer-email',
                'type'     => 'text',
				'title'    => 'Footer email',
				'default'    => 'noreply@envato.com',
            ),
            array(
                'id'       => 'foot2',
                'type'     => 'section',
                'title'    => ' ',
                'indent'   => true, // Indent all options below until the next 'section' option is set.
            ),
            array(
                'id'       => $opt_prefix.'-foot-right-time-1st-line',
                'type'     => 'text',
				'title'    => 'Footer right time 1st line',
				'default'    => 'Mon-Fri: 7:00am-7:00pm',
            ),
            array(
                'id'       => $opt_prefix.'-foot-right-time-2nd-line',
                'type'     => 'text',
				'title'    => 'Footer right time 2nd line',
				'default'    => 'Sat-Sun: 10:00am-5:00pm',
            ),
            array(
                'id'       => $opt_prefix.'-foot-right-last',
                'type'     => 'editor',
					 'title'    => 'Footer right Last',
            ),
            array(
                'id'   => 'foot-section-info2',
                'type' => 'info',
                'desc' => esc_html__( 'And now you can add more fields below and outside of the indent.', 'laundry' ),
            ),
			
    )));
    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'modal Settings', 'laundry' ),
        'id'               => 'modal_settings',
        'desc'             => esc_html__( 'modal for email subscription', 'laundry' ),
        'customizer_width' => '400px',
        'icon'             => 'el el-website-alt',
        'fields'           => array(
            array(
                'id'       => $opt_prefix.'-is_modal_enable',
                'type'     => 'switch', 
                'title'    => esc_html__('modal', 'laundry'),
                'subtitle' => esc_html__('Enable or Disable modal on site', 'laundry'),
                'default'  => false,
                'on'       => esc_html__('Enable', 'laundry'),
                'off'      => esc_html__('Disable', 'laundry'),
            ),
            array(
                'id'       => 'modal_title',
                'type'     => 'text',
                'title'    => esc_html__('modal Title', 'laundry'),
                'subtitle' => esc_html__('modal title which one will be shown at top of modal', 'laundry'),
                'default'  => 'Newsletter signup'
            ),
            array(
                'id'       => 'modal_mc_form',
                'type'     => 'textarea',
                'title'    => esc_html__('Order Form', 'laundry'),
                'subtitle' => esc_html__('Order form murkup', 'laundry'),
                'default'  => ''
            ),
        )
    ) );
   
    Redux::setSection( $opt_name, array(
		'title'            => esc_html__('Contact', 'laundry'),
		'id'               => 'contact_settings',
		'desc'             => esc_html__('Contact', 'laundry'),
		'customizer_width' => '400px',
		'icon'             => 'el el-th-large',
		'fields'           => array(
            array(
				'id'       => $opt_prefix.'-display-gmap',
				'type'     => 'switch',
				'title'    => esc_html__('Display Google Map', 'laundry'),
				'subtitle' => esc_html__('Display Google Map', 'laundry'),
				'default'  => true,
				'on'	   => esc_html__('Enable', 'laundry'),
				'off'	   => esc_html__('Disable', 'laundry'),
			),
            array(
				'id'       => $opt_prefix.'-gmap-api-key',
				'type'     => 'text',
				'title'    => esc_html__('Google Map Api Key', 'laundry'),
				'subtitle' => esc_html__('Set Google Map Api Key', 'laundry'),
				'default'  => ''
			),
            array(
				'id'       => $opt_prefix.'-gmap-zoom',
				'type'     => 'text',
				'title'    => esc_html__('Google Map Zoom Level', 'laundry'),
				'subtitle' => esc_html__('Set Google Map Zoom Level', 'laundry'),
				'default'  => '14'
			),
            array(
				'id'       => $opt_prefix.'-gmap-latitude',
				'type'     => 'text',
				'title'    => esc_html__('Google Map Latitude', 'laundry'),
				'subtitle' => esc_html__('Set Google Map Latitude', 'laundry'),
				'default'  => '55.8610112'
			),
			array(
				'id'       => $opt_prefix.'-gmap-longitude',
				'type'     => 'text',
				'title'    => esc_html__('Google Map Longitude', 'laundry'),
				'subtitle' => esc_html__('Set Google Map Longitude', 'laundry'),
				'default'  => '-4.2547319'
			),
    )));
	Redux::setSection( $opt_name, array(
		'title'            => esc_html__('Typography', 'laundry'),
		'id'               => 'fonts_settings',
		'desc'             => esc_html__('Typography', 'laundry'),
		'customizer_width' => '400px',
		'icon'             => 'el el-font',
		'fields'           => array(
            array(
				'id'       => $opt_prefix.'-body-typography',
				'type'     => 'typography',
				'title'    => esc_html__( 'Body Typography', 'laundry' ),
				'subtitle' => esc_html__( 'Select body font family, size, color and weight.', 'laundry' ),
				'text-align' => false,
				'color' => false,
				'font-weight' => false,
				'font-style' => false,
				'subsets' => false,
				'default'     => array(
					'font-family' => 'Lato',
					'google'      => true,
					'font-size'   => '16px',
				),
                'line-height' => false,
                'output' => false,
			),
            array(
				'id'       => $opt_prefix.'-heading-typography',
				'type'     => 'typography',
				'title'    => esc_html__( 'Heading Typography', 'laundry' ),
				'subtitle' => esc_html__( 'Select heading font family and weight.', 'laundry' ),
				'text-align' => false,
				'color' => false,
				'font-weight' => false,
				'font-style' => false,
				'font-size' => false,
				'subsets' => false,
				'default'     => array(
					'font-family' => 'Rubik',
					'google'      => true,
				),
                'output' => false,
                'line-height' => false,
			),
    )));
	
	Redux::setSection( $opt_name, array(
            'title'            => esc_html__( 'Extra Settings', 'laundry' ),
            'id'               => 'extra_settings',
            'desc'             => esc_html__( 'These are really basic fields!', 'laundry' ),
            'customizer_width' => '400px',
            'icon'             => 'el el-share',


            'fields'  => array(
            	 array(
				'id'       => $opt_prefix.'-slug_postype_laundry_services',
				'type'     => 'text',
				'title'    => esc_html__('Slug Laundry Services', 'laundry'),
				'subtitle' => esc_html__('Change Laundary Service Slug Name', 'laundry'),
				'default'  => '' //laundry_services
				),

                array(
                        'id'       => 'extra_css',
                        'type'     => 'ace_editor',
                        'title'    => esc_html__( 'Extra CSS', 'laundry' ),
                        'subtitle' => esc_html__( 'Extra CSS just after theme styles', 'laundry' ),
                        'mode' => 'css'
                ),
            )
    ));